@@ -1713,30 +1713,39 @@ typeに適用するテーマ名<br />
 </ul>
 </td></tr>
 <tr><td colspan="4"><hr></td></tr>
+
 <tr><td class="DetailTitle">indexスレッドプレビュー数</td>
 <td><input type="text" size="8" name="BBS_THREAD_NUMBER" value="" /></td>
-<td class="DetailTitle">cookie確認</td>
-<td><input type="checkbox" name="SUBBBS_CGI_ON" value="checked" />確認あり</td></tr>
+<td class="DetailTitle">文字参照変換</td>
+<td><input type="checkbox" name="BBS_UNICODE" value="change" />変換する</td></tr>
 <tr><td class="DetailTitle">indexプレビューレス数</td>
 <td><input type="text" size="8" name="BBS_CONTENTS_NUMBER" value="" /></td>
-<td class="DetailTitle">&nbsp;&nbsp;&nbsp;&nbsp;名前cookie保存</td>
-<td><input type="checkbox" name="BBS_NAMECOOKIE_CHECK" value="checked" />保存</td></tr>
+<td class="DetailTitle">cookie確認</td>
+<td><input type="checkbox" name="SUBBBS_CGI_ON" value="checked" />確認あり</td></tr>
 <tr><td class="DetailTitle">indexレス内容表示行数</td>
 <td><input type="text" size="8" name="BBS_LINE_NUMBER" value="" /></td>
-<td class="DetailTitle">&nbsp;&nbsp;&nbsp;&nbsp;メールcookie保存</td>
-<td><input type="checkbox" name="BBS_MAILCOOKIE_CHECK" value="checked" />保存</td></tr>
+<td class="DetailTitle">&nbsp;&nbsp;&nbsp;&nbsp;名前cookie保存</td>
+<td><input type="checkbox" name="BBS_NAMECOOKIE_CHECK" value="checked" />保存</td></tr>
 <tr><td class="DetailTitle">indexメニュー数</td>
 <td><input type="text" size="8" name="BBS_MAX_MENU_THREAD" value="" /></td>
+<td class="DetailTitle">&nbsp;&nbsp;&nbsp;&nbsp;メールcookie保存</td>
+<td><input type="checkbox" name="BBS_MAILCOOKIE_CHECK" value="checked" />保存</td></tr>
+<tr><td class="DetailTitle">携帯からのスレッドプレビュー数</td>
+<td><input type="text" size="8" name="BBS_MB_THREAD_NUMBER" value="" /></td>
 <td class="DetailTitle">スレッド作成画面</td>
 <td><input type="checkbox" name="BBS_PASSWORD_CHECK" value="checked" />別画面</td></tr>
-<tr><td class="DetailTitle">文字参照変換</td>
-<td><input type="checkbox" name="BBS_UNICODE" value="change" />変換する</td>
+<tr><td class="DetailTitle">携帯からのプレビューレス数</td>
+<td><input type="text" size="8" name="BBS_MB_CONTENTS_NUMBER" value="" /></td>
 <td class="DetailTitle">スレッド作成確認画面</td>
 <td><input type="checkbox" name="BBS_NEWSUBJECT" value="checked" />確認あり</td></tr>
-<tr><td class="DetailTitle">曜日文字</td>
-<td><input type="text" size="20" name="BBS_YMD_WEEKS" value="" /></td>
+<tr><td class="DetailTitle">携帯からのレス内容表示行数</td>
+<td><input type="text" size="8" name="BBS_MB_LINE_NUMBER" value="" /></td>
 <td class="DetailTitle">キャップのみスレッド作成可能</td>
-<td><input type="checkbox" name="BBS_THREADCAPONLY" value="checked" />有効</td></tr>
+<td><input type="checkbox" name="BBS_THREADCAPONLY" value="checked" />有効</td>
+<tr><td class="DetailTitle">曜日文字</td>
+<td><input type="text" size="20" name="BBS_YMD_WEEKS" value="" /></td></tr>
+<td colspan="2"></td></tr>
+
 <tr><td colspan="4"><hr></td></tr>
 <tr><td colspan="4" align="right">
 <button onclick="Zeromin.getSetting().save('div#settingOther')">
@@ -1800,12 +1809,16 @@ SETTING.TXTから値を見ることが出来ます。
 <td><input type="checkbox" name="BBS_IMG_REQUIRE_REMOVE_KEY" value="checked" />必須にする</td>
 <td class="DetailTitle">アップロード時にダウンロードキーを必須にする</td>
 <td><input type="checkbox" name="BBS_IMG_REQUIRE_DOWNLOAD_KEY" value="checked" />必須にする</td></tr>
+<tr><td class="DetailTitle">スレッド作成時にファイルのアップロードを許可する</td>
+<td><input type="checkbox" name="BBS_IMG_UPLOAD_THREAD" value="checked" />許可</td>
+<td class="DetailTitle">ファイルの有効期限(秒単位：0で無限)</td>
+<td><input type="text" size="8" name="BBS_IMG_EXPIRES" value="" /></td></tr>
 <tr><td class="DetailTitle">アップロードを許可する拡張子</td>
 <td>
 <textarea name="BBS_IMG_ALLOWED_EXT" cols="10" rows="5"></textarea>
 </td>
-<td class="DetailTitle">ファイルの有効期限(秒単位：0で無限)</td>
-<td><input type="text" size="8" name="BBS_IMG_EXPIRES" value="" /></td></tr>
+<td></td>
+</tr>
 <tr><td colspan="4"><hr></td></tr>
 <tr><td colspan="4" align="right">
 <button onclick="Zeromin.getSetting().save('div#settingUpload')">
