@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 230 2007-02-13 14:30:18Z hikarin $
+# $Id: BBS.pm 301 2007-03-03 13:51:21Z hikarin $
 #
 
 package Img0ch::App::BBS;
@@ -38,6 +38,7 @@ BEGIN {
 sub new {
     my ( $iClass, $iKernel, @args ) = @_;
     bless {
+        __annotation                => {},
         _config                     => $iKernel->get_config(),
         _host                       => '',
         _ip                         => '',
@@ -62,6 +63,7 @@ sub new {
         __resmax                    => 0,
         __setting                   => undef,
         __sage                      => 0,
+        __stash                     => {},
         __subject                   => undef,
         __template_tag_confirm      => [],
         __template_tag_error        => [],
@@ -114,10 +116,13 @@ sub init {
     my $iSetting = Img0ch::Setting->new($iBBS);
     $iSetting->load();
     $iApp->{__setting} = $iSetting;
-    $iApp->{__now}     = $iRequest->now();
+
+    my $key = $iRequest->key();
+    my $now = $iRequest->now();
+    $key > $now and $key = $now;
+    $iApp->{__now} = $now;
 
     require Img0ch::Thread;
-    my $key = $iRequest->key();
     my $iThread = Img0ch::Thread->new( $iBBS, $key );
     $iApp->{__agent}    = $iRequest->agent();
     $iApp->{__key}      = $key;
@@ -300,6 +305,27 @@ sub validate {
         $iApp->{__error} = 'TOO_MANY_ANKERS';
         return 0;
     }
+    if ( $iConfig->get('EnableAnnotation') ) {
+        my @new_comment;
+        my $hash = {};
+        my $seen = {};
+        for my $line ( split "\n", $comment ) {
+            if ($line !~ /\A\@(\w+)\s*[\s=]\s*(.+)\r?\z/xms) {
+                push @new_comment, $line;
+                next;
+            }
+            my ( $key, $value ) = ( $1, $2 );
+            if ($seen->{$key}) {
+                push @new_comment, $line;
+                next;
+            }
+            $seen->{$key} = 1;
+            $hash->{$key} = $value;
+            $line =~ s/\A\@(\w+)[\s=]\s*(.+)\r?\z//xms;
+        }
+        %{$iApp->{__annotation}} = %$hash;
+        $comment = join "\n", @new_comment;
+    }
     $comment =~ tr/\r\t//d;
     $comment =~ s/\A\s+//xms;
     $comment =~ s/\s+\z//xms;
@@ -485,6 +511,7 @@ sub post {
     my $mode     = $iSetting->get('BBS_MODE');
     if ((      ( $mode eq 'picture' and !$mkthread )
             or ( $mode eq 'news'    and $mkthread )
+            or ( $iSetting->is_checked('BBS_IMG_UPLOAD_THREAD') and $mkthread )
         )
         and $iRequest->is_uploadable('file')
         )
@@ -519,7 +546,8 @@ sub post {
             my $iKernel = $iApp->{__kernel};
             my $path = join '/', $iConfig->get('SystemPath'), '1000.txt';
             local ( *FH, $! );
-            open *FH, "<${path}" or $iKernel->throw_io_exception($path);
+            open *FH, "<${path}" ## no critic
+                or $iKernel->throw_io_exception($path);
             $content = do { local $/ = undef; <FH> };
             close *FH or $iKernel->throw_io_exception($path);
         }
@@ -602,8 +630,8 @@ sub update_subback {
     my $iTemplate = Img0ch::Template->new(
         $iBBS,
         {   file    => 'subback',
+            request => $iApp->{_request},
             setting => $iSetting,
-            version => $iApp->{_request}->credit(),
         }
     );
     $iTemplate->param($param);
@@ -629,17 +657,20 @@ sub update_index {
         require Img0ch::Setting;
         $iSetting = Img0ch::Setting->new($iBBS);
         $iSetting->load();
+        $iApp->{__setting} = $iSetting;
     }
     my $iSubject = $iApp->{__subject};
     if ( !$iSubject ) {
         require Img0ch::Subject;
         $iSubject = Img0ch::Subject->new($iBBS);
         $iSubject->load();
+        $iApp->{__subject} = $iSubject;
     }
     my $iThread = $iApp->{__thread};
     if ( !$iThread ) {
         require Img0ch::Thread;
         $iThread = Img0ch::Thread->new( $iBBS, 0 );
+        $iApp->{__thread} = $iThread;
     }
     $iThread->enable_xhtml_break( $iConfig->get('EnableXHTMLBreak') ? 1 : 0 );
 
@@ -692,6 +723,7 @@ sub update_index {
         $i++;
     }
 
+    require Img0ch::Metadata;
     my $iMeta       = $iApp->{__meta} || Img0ch::Metadata->new($iBBS);
     my $head        = $iMeta->head();
     my $meta        = $iMeta->meta();
@@ -731,8 +763,8 @@ sub update_index {
     my $iTemplateIndex = Img0ch::Template->new(
         $iBBS,
         {   file    => 'index',
+            request => $iRequest,
             setting => $iSetting,
-            version => $iRequest->credit(),
         }
     );
     $iTemplateIndex->param($index_param);
@@ -741,8 +773,8 @@ sub update_index {
     my $iTemplateMobile = Img0ch::Template->new(
         $iBBS,
         {   file    => 'i_index',
+            request => $iRequest,
             setting => $iSetting,
-            version => $iRequest->credit(),
         }
     );
     $iTemplateMobile->param($mi_param);
@@ -945,8 +977,12 @@ sub get_ip_int { $_[0]->{_ip_int} }
 
 sub get_remote_host { $_[0]->{_host} }
 
+sub get_annotation { $_[0]->{__annotation}->{$_[1]} || '' }
+
 sub set_error { $_[0]->{__error} = $_[1]; return; }
 
+sub set_error_argument { $_[0]->{__error_args} = $_[1]; return; }
+
 sub bbs { $_[0]->{__bbs} }
 
 sub cap { $_[0]->{__cap} }
@@ -965,6 +1001,15 @@ sub thread { $_[0]->{__thread} }
 
 sub upload { $_[0]->{__upload} }
 
+sub stash {
+    my ( $iApp, $key, $value ) = @_;
+    if ( $value ) {
+        $iApp->{__stash}->{$key} = $value;
+        return;
+    }
+    return $iApp->{__stash}->{$key};
+}
+
 sub _switch {
     my ($iApp) = @_;
     my $agent  = $iApp->{__agent};
@@ -983,8 +1028,8 @@ sub _switch {
             my $iTemplate = Img0ch::Template->new(
                 $iBBS,
                 {   file    => 't_form',
+                    request => $iRequest,
                     setting => $iSetting,
-                    version => $iRequest->credit(),
                 }
             );
             $iTemplate->param(
@@ -1100,18 +1145,18 @@ sub redirect_success {
 
     if ($iRequest->param('js')) {
         $iRequest->send_http_header( 'text/javascript', 'UTF-8' );
-        print ${$iRequest->get_json({
+        $iRequest->print($iRequest->get_json({
             ok => 1,
             error => '',
-            errstr => '' })};
+            errstr => '' }));
     }
     else {
         require Img0ch::Metadata;
         my $iTemplate = Img0ch::Template->new(
             $iBBS,
             {   file    => 'redirect',
+                request => $iRequest,
                 setting => $iApp->{__setting},
-                version => $iRequest->credit(),
             }
         );
         $iTemplate->param(
@@ -1130,7 +1175,8 @@ sub redirect_success {
 sub redirect_error {
     my ( $iApp, $template, $cs, $filter, $callback ) = @_;
     my $iConfig = $iApp->{_config};
-    my $iObject = $iApp->{__bbs} || $iApp->{__kernel};
+    my $iKernel = $iApp->{__kernel};
+    my $iObject = $iApp->{__bbs} || $iKernel;
     my $iRequest = $iApp->{_request};
 
     require Img0ch::Error;
@@ -1144,10 +1190,14 @@ sub redirect_error {
         $long =~ s/{!$subs!}/$value/gxms;
     }
 
+    my $charset = $iKernel->get_encoding(1);
     my $ip   = $iApp->{_host} || $iApp->{_ip} || $iRequest->ip();
-    my $name = $iApp->{__param_FROM} || $iRequest->param('FROM');
-    my $mail = $iApp->{__param_mail} || $iRequest->param('mail');
-    my $message = $iApp->{__param_MESSAGE} || $iRequest->param('MESSAGE');
+    my $name = $iApp->{__param_FROM}
+        || $iRequest->param_multibyte( 'FROM', $charset );
+    my $mail = $iApp->{__param_mail}
+        || $iRequest->param_multibyte( 'mail', $charset );
+    my $message = $iApp->{__param_MESSAGE}
+        || $iRequest->param_multibyte( 'MESSAGE', $charset );
     $callback and $callback->( $iApp, $long );
 
     if ($iRequest->param('js')) {
@@ -1155,18 +1205,18 @@ sub redirect_error {
         $iRequest->send_http_header( 'text/javascript', 'UTF-8' );
         $long =~ tr/\r//d;
         my $icode = Unicode::Japanese->getcode($long);
-        print ${$iRequest->get_json({
+        $iRequest->print($iRequest->get_json({
             ok => 0,
             error => $error,
-            errstr => Unicode::Japanese->new( $long, $icode )->get() })};
+            errstr => Unicode::Japanese->new( $long, $icode )->get() }));
     }
     else {
         require Img0ch::Template;
         my $iTemplate = Img0ch::Template->new(
             $iObject,
             {   file    => ( $template || 'error' ),
+                request => $iRequest,
                 setting => $iApp->{__setting},
-                version => $iRequest->credit(),
             }
         );
         $iTemplate->param(
@@ -1867,6 +1917,26 @@ $host
 
 現在の投稿元(リモートホスト)の文字列を返します。
 
+=head2 get_annotation
+
+=over 4
+
+=item Arguments
+
+$annotation_key
+
+=item Return Value
+
+$annotation_value
+
+=back
+
+本文に付けられたアノテーションに対応する値を取得します。
+対応する値が存在しない場合はナルストリングが返されます。
+
+img0ch-config.cgiにI<EnableAnnotation>が入っていない場合
+常にこの関数はナルストリングが返されます。
+
 =head2 set_error
 
 =over 4
@@ -2037,6 +2107,26 @@ $iUpload (Img0ch::Upload)
 I<Img0ch::Upload>オブジェクトを返します。
 アップロードされることが分かっている場合に利用可能です。
 
+=head2 stash
+
+=over 4
+
+=item Arguments
+
+$key, $value?
+
+=item Return Value
+
+none(setter) or $value(getter)
+
+=back
+
+Img0ch::App::BBSのオブジェクト内部に保管されている
+仮想的なグローバル値を設定または取得します。
+
+引数にI<$value>がある場合返り値はありません。
+引数がI<$key>のみの場合はそれに対応する値を返します。
+
 =head2 add_form_tag
 
 =over 4
