@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Read.pm 215 2007-02-10 13:05:38Z hikarin $
+# $Id: Read.pm 317 2007-03-04 14:11:35Z hikarin $
 #
 
 package Img0ch::App::Read;
@@ -54,6 +54,8 @@ sub new {
         _param_raw              => '',
         _plugin                 => undef,
         __range_read            => [],
+        __read_from             => 0,
+        __read_to               => 0,
         _request                => Img0ch::Request->new(@args),
         _setting                => undef,
         __template_tag_error    => [],
@@ -151,6 +153,8 @@ sub get_param {
         || '';
 }
 
+sub get_param_int { Img0ch::Kernel::intval(shift->get_param(@_)) }
+
 sub _load_thread {
     my ( $iApp, $template_vars, $option ) = @_;
     my $key      = $iApp->{_param_key};
@@ -169,17 +173,22 @@ sub _load_thread {
     my $plugin = $iPlugin->iterator( $option->{type}, sub { ${ $_[3] } } );
     my $read_thread_stack = [];
     my $read_range        = $iApp->{__range_read};
-    my $nofirst           = $iApp->{_param_nofirst};
-    my $single            = $iApp->{_param_single};
     my $raw               = $iApp->{_param_raw};
     my $count             = $iApp->{__thread_count};
     my $loop              = int( $count / 100 ) + 1;
-    my $st                = $read_range->[0];
-    my $to                = $read_range->[-1];
     my $max               = $iConfig->get_int('ResMAX') || 1000;
     my $omit              = $iConfig->get('OmitDefaultNoName');
     my $noname            = $iSetting->get('BBS_NONAME_NAME');
 
+    my $st = $iApp->{__read_from};
+    my $to = $iApp->{__read_to};
+    my $parameter = {
+        line    => $iApp->get_param_int('LINE'),
+        nofirst => $iApp->{_param_nofirst},
+        single  => $iApp->{_param_single},
+        raw     => $raw,
+    };
+
     if (    !$iApp->{_param_nofirst}
         and !$iApp->{_param_single}
         and $read_range->[0] == 1 )
@@ -190,23 +199,16 @@ sub _load_thread {
         my $date  = $id ? ( join ' ', $first->[2], $id ) : $first->[2];
         my $text  = $first->[4];
         ( $mobile and $omit and $name eq $noname ) and $name = '';
-        $plugin->(
-            $key, $count, 1,
-            \$text,
-            {   nofirst => $nofirst,
-                single  => $single,
-                raw     => $raw,
-            }
-        );
+        $plugin->( $key, $count, 1, \$text, $parameter );
         push @{$read_thread_stack},
             {
-            'index'   => 1,
-            'resno'   => 1,
-            'name'    => $name,
-            'mail'    => $first->[1],
-            'date'    => $date,
-            'text'    => $text,
-            'isFirst' => 1,
+            index   => 1,
+            resno   => 1,
+            name    => $name,
+            mail    => $first->[1],
+            date    => $date,
+            text    => $text,
+            isFirst => 1,
             };
         shift @{$read_range};
     }
@@ -218,23 +220,16 @@ sub _load_thread {
         my $date = $id ? ( join ' ', $res->[2], $id ) : $res->[2];
         my $text = $res->[4];
         ( $mobile and $omit and $name eq $noname ) and $name = '';
-        $plugin->(
-            $key, $count, $i,
-            \$text,
-            {   nofirst => $nofirst,
-                single  => $single,
-                raw     => $raw,
-            }
-        );
+        $plugin->( $key, $count, $i, \$text, $parameter );
         push @{$read_thread_stack},
             {
-            'index'   => $i,
-            'resno'   => $i,
-            'name'    => $name,
-            'mail'    => $res->[1],
-            'date'    => $date,
-            'text'    => $text,
-            'isFirst' => 0,
+            index   => $i,
+            resno   => $i,
+            name    => $name,
+            mail    => $res->[1],
+            date    => $date,
+            text    => $text,
+            isFirst => 0,
             };
     }
 
@@ -242,14 +237,14 @@ sub _load_thread {
     for ( my $i = 1; $i < $loop; $i++ ) {
         push @{$link},
             {
-            'start' => ( $i * 100 + 1 ),
-            'end'   => ( ( $i + 1 ) * 100 ),
+            start => ( $i * 100 + 1 ),
+            end   => ( ( $i + 1 ) * 100 ),
             };
     }
 
     my ( $reader, $read_res, $read_res_prev ) = ( undef, 100, 99 );
     if ($mobile) {
-        my $cnum = $iRequest->param_int('RES')
+        my $cnum = $iApp->get_param_int('RES')
             || $iSetting->get_int('BBS_MB_CONTENTS_NUMBER')
             || 1;
         $read_res = $read_res_prev = $cnum;
@@ -266,14 +261,15 @@ sub _load_thread {
     my $iTemplate = Img0ch::Template->new(
         $iBBS,
         {   file    => $option->{template},
+            request => $iRequest,
             setting => $iSetting,
-            version => $iRequest->credit(),
         }
     );
 
     my $r90  = ( $count >= $max - int( $max / 10 ) ? 1 : 0 );
     my $r95  = ( $count >= $max - int( $max / 20 ) ? 1 : 0 );
     my $r100 = ( $count > $max                     ? 1 : 0 );
+    $mobile or $st--;
     $iTemplate->param(
         {   ( map { %{$_} } @{ $iApp->{__template_tag_read} } ),
             '90'     => $r90,
@@ -296,7 +292,7 @@ sub _load_thread {
 #            'MailByCookie' => ( $iRequest->cookie('MAIL') || '' ),
             'MailByCookie' => '',
             'META'         => $iMeta->meta(),
-            'PrevEnd'      => $st + $read_res,
+            'PrevEnd'      => ( $st || 1 ),
             'PrevStart' =>
                 ( $st - $read_res_prev < 1 ? 1 : $st - $read_res_prev ),
             'ReadCGIURI' => $reader,
@@ -321,29 +317,51 @@ sub _parse_from_request {
     if ( my $path_info = $iRequest->path_info() ) {
         my @path = split '/', $path_info;
         my $raw;
-        if ( @path > 4 ) {
-            $raw = $path[4];
-            my $extend_param = $path[3];
+
+        'test' =~ /\A(\w+)\z/xms;
+        $path[1] =~ /\A([\w\-]+)\z/xms;
+        my $bbs = $iApp->{_param_bbs} = $1;
+        '0000000000' =~ /\A(\d+)\z/xms;
+        $path[2] =~ /\A(\d{9,10})\z/xms;
+        my $key = $iApp->{_param_key} = $1;
+
+        my $extent_param_parser = sub {
+            my ( $iApp, $parameter ) = @_;
+            my $extend_param = $parameter;
             $extend_param =~ s/\A.*?[\!\?]//xms;
             $iApp->{_query_with_extend_params} = $extend_param;
             my $extend_params = {};
+            my $found = 0;
             for my $chunk ( split /[&;]/xms, $extend_param ) {
                 my ( $name, $value ) = split /[\+=]/, $chunk;
                 $extend_params->{$name}
                     = Img0ch::Kernel::escape_html_entities($value);
+                $found++;
             }
             %{ $iApp->{_extend_params} } = %{$extend_params};
+            return $found;
+        };
+
+        if ( $key ne '0000000000' and @path >= 4 ) {
+            if ($mobile) {
+                my $query = '';
+                $raw = $path[4] || '';
+                $raw ? ( $query = $path[3] ) : ( $raw = $path[3] || '' );
+                $extent_param_parser->( $iApp, $query );
+            }
+            else {
+                $raw = $path[3] || '';
+            }
+        }
+        elsif ( $bbs ne 'test' and @path >= 3 ) {
+            $raw = $path[3] || ( $mobile ? $path[2] : '' );
+            $extent_param_parser->( $iApp, $path[2] );
         }
         else {
             $raw = $path[3] || ( $mobile ? $path[2] : '' );
         }
-
         $iApp->{_param_raw} = $raw;
-        $raw =~ s/([acCi]+)\z//xms;
-        ( $path[1] || 'test' ) =~ /([\w\-]+)/xms;
-        $iApp->{_param_bbs} = $1;
-        ( $path[2] || '0000000000' ) =~ /(\d{9,10})/xms;
-        $iApp->{_param_key} = $1;
+        $raw =~ s/[acCi]\z//xms;
 
         my $main_parser = sub {
             my ($chunk) = @_;
@@ -449,18 +467,26 @@ sub _normalize {
     my $temp_read_from = $temp_range->[0] || 1;
     my $temp_read_to   = $temp_range->[-1] || $temp_read_from;
     my ( $real_read_from, $real_read_to, $read_by_const ) = (
-        0, 0, ( $iApp->{_setting}->get_int('BBS_MB_CONTENTS_NUMBER') || 1 )
+        0, 0, ( $iApp->get_param_int('RES') ||
+        $iApp->{_setting}->get_int('BBS_MB_CONTENTS_NUMBER') || 1 )
     );
 
     if ($is_mobile) {
         $read_by_const--;
-        if ( $raw =~ /i[acCi]*\z/xms ) {
+        if ( $raw =~ /\A(n)?[acCi]*\z/xms ) {
             $last = 1;
             # $temp_read_to = 1001 ( ResMAX )
             #     =>
             # $temp_read_to = 10 ( $read_by_const )
+            $nofirst = $iApp->{_param_nofirst} = $1 ? 1 : 0;
             $temp_read_to = $read_by_const;
-            $nofirst = $iApp->{_param_nofirst} = 0;
+        }
+        elsif ( $raw =~ /l(\d+)(n)?/xms ) {
+            my $read_range = $1;
+            $last = 1;
+            $nofirst = $iApp->{_param_nofirst} = $2 ? 1 : 0;
+            $read_by_const = $read_range;
+            $temp_read_to = $read_range - 1;
         }
         else {
             $nofirst = $iApp->{_param_nofirst} = 1;
@@ -474,6 +500,8 @@ sub _normalize {
         my $read_to = $real_read_from + $read_by_const;
         $real_read_to = $res_count > $read_to ? $read_to : $res_count;
         @{$temp_range} = $real_read_from .. $real_read_to;
+        $iApp->{__read_from} = $real_read_from;
+        $iApp->{__read_to}   = $real_read_to;
         if (!$nofirst) {
             $real_read_from = 1;
             $temp_range->[0] != 1 and unshift @{$temp_range}, 1;
@@ -494,6 +522,8 @@ sub _normalize {
             ? $real_read_from + $read_by_const
             : $res_count
             );
+        $iApp->{__read_from} = $temp_read_from;
+        $iApp->{__read_to}   = $real_read_to;
     }
 #    ( $is_mobile and $real_read_to - $real_read_from > $read_by_const )
 #        and $real_read_from = $real_read_to - $read_by_const;
@@ -563,13 +593,13 @@ sub _redirect_error {
                     my $text = $res->[4];
                     push @{$res_stack},
                         {
-                        'num'     => $i,
-                        'resno'   => $i,
-                        'name'    => $res->[0],
-                        'mail'    => $res->[1],
-                        'date'    => $date,
-                        'text'    => $text,
-                        'isFirst' => ( $i == 1 ? 1 : 0 ),
+                        num     => $i,
+                        resno   => $i,
+                        name    => $res->[0],
+                        mail    => $res->[1],
+                        date    => $date,
+                        text    => $text,
+                        isFirst => ( $i == 1 ? 1 : 0 ),
                         };
                 }
                 $dat_bytes  = $iPThread->size();
@@ -589,29 +619,29 @@ sub _redirect_error {
     my $iTemplate = Img0ch::Template->new(
         ( $iBBS || $iKernel ),
         {   file    => 'not_found',
+            request => $iRequest,
             setting => $iApp->{_setting},
-            version => $iRequest->credit(),
         }
     );
     $iTemplate->param(
         {   ( map { %{$_} } @{ $iApp->{__template_tag_error} } ),
-            'Archive' => $archive_path,
-            'Banner' => $banner,
-            'DatByteSize' => $dat_bytes,
-            'DatKByteSize' => int($dat_bytes / 1024),
-            'IsArchived' => $archive_found,
-            'IsError' => $is_error,
-            'IsPooled' => $pool_found,
-            'Token1' => substr( $key, 0, 4 ),
-            'Token2' => substr( $key, 0, 5 ),
-            'LongErrorStr' => $long,
-            'META'         => $meta,
-            'ReadCGIURI' => $reader,
-            'ResCount' => $res_count,
-            'ShortErrorStr' => $long,
-            'Subject' => $subject,
-            'Thread' => $res_stack,
-            'ZThread' => $res_stack,
+            Archive => $archive_path,
+            Banner => $banner,
+            DatByteSize => $dat_bytes,
+            DatKByteSize => int($dat_bytes / 1024),
+            IsArchived => $archive_found,
+            IsError => $is_error,
+            IsPooled => $pool_found,
+            Token1 => substr( $key, 0, 4 ),
+            Token2 => substr( $key, 0, 5 ),
+            LongErrorStr => $long,
+            META         => $meta,
+            ReadCGIURI => $reader,
+            ResCount => $res_count,
+            ShortErrorStr => $long,
+            Subject => $subject,
+            Thread => $res_stack,
+            ZThread => $res_stack,
         }
     );
     $iApp->{_request}->send_http_header('text/html');
