@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 122 2007-01-23 13:51:04Z hikarin $
+# $Id: BBS.pm 164 2007-02-02 14:52:06Z hikarin $
 #
 
 package Img0ch::BBS;
@@ -58,9 +58,13 @@ sub get_common_repos { $_[0]->{_repos} }
 
 sub get_system_repos { $_[0]->{_system} }
 
-sub id { $_[0]->{_id} }
+sub get_id { $_[0]->{_id} }
 
-sub bbs { $_[0]->{_dir} }
+*id = \&get_id;
+
+sub get_name { $_[0]->{_dir} }
+
+*bbs = \&get_name;
 
 sub get_repos_path {
     my ( $iBBS, @dirs ) = @_;
@@ -90,8 +94,8 @@ Img0ch::BBS - 掲示板を管理するクラス
   use Img0ch::BBS
 
   my $iBBS = Img0ch::BBS->new($iKernel, $bbs);
-  my $id = $iBBS->id();
-  my $bbs = $iBBS->bbs();
+  my $id = $iBBS->get_id();
+  my $bbs = $iBBS->get_name();
 
 =head1 DESCRIPTION
 
@@ -163,7 +167,7 @@ $iReposSystem
 掲示板内のみ有効なシステムレポジトリのオブジェクトを返します。
 この関数はバージョンが2.1.x-3.xでのみ使用可能です。
 
-=head2 id
+=head2 get_id
 
 =over 4
 
@@ -179,7 +183,23 @@ $bbs_id
 
 現在の掲示板のIDを返します。存在しない場合は0を返します。
 
-=head2 bbs
+=head2 id
+
+=over 4
+
+=item Arguments
+
+none
+
+=item Return Value
+
+$bbs_id
+
+=back
+
+get_id()と同様ですが、今後削除される予定の非推奨の関数です。
+
+=head2 get_name
 
 =over 4
 
@@ -195,6 +215,22 @@ $bbs_dir
 
 現在の掲示板のディレクトリ名を返します。存在しない場合はナルストリングを返します。
 
+=head2 get_name
+
+=over 4
+
+=item Arguments
+
+none
+
+=item Return Value
+
+$bbs_dir
+
+=back
+
+get_name()と同様ですが、今後削除される予定の非推奨の関数です。
+
 =head2 path
 
 =over 4
