@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Error.pm 217 2007-02-12 13:28:00Z hikarin $
+# $Id: Error.pm 250 2007-02-17 13:21:36Z hikarin $
 #
 
 package Img0ch::Error;
@@ -31,14 +31,14 @@ sub new {
         $bbs     = $iObject->get_name() || 'test';
         $common  = $iObject->get_common_repos();
     }
-    elsif ( $class eq 'Img0ch::Maple' ) {
+    elsif ( $class eq 'Img0ch::Kernel' or $class eq 'Img0ch::Maple' ) {
         $iKernel = $iObject;
         $bbs     = 'test';
         $common  = $iKernel->get_repos( $iKernel->get_repos_path('common') );
     }
     else {
         Img0ch::Kernel->throw_exception(
-            'Img0ch::BBS or Img0ch::Maple not given');
+            'Img0ch::BBS or Img0ch::Maple(Img0ch::Kernel) not given');
     }
 
     my $date = time();
@@ -94,6 +94,9 @@ sub get {
             if ( $key eq $errid ) {
                 close *FH or $iKernel->throw_io_exception($path);
                 $iError->{__cache} = $key;
+                my $iRepos = $iError->{__error};
+                $iRepos->set( "I:E.${errid}", $errmsg );
+                $iRepos->save();
                 return $errmsg;
             }
         }
@@ -135,9 +138,9 @@ Img0ch::Error - エラー処理を行うクラス
   my $iError = Img0ch::Error->new($iBBS, $key, $ip);
 
   # INVALID_POSTのメッセージを取り出す
-  my $bbspath = $iError->get('INVALID_POST');
+  my $errstr = $iError->get('INVALID_POST');
   # エラー記録を行う
-  my $resmax = $iError->record();
+  my $true_or_false = $iError->record();
 
 =head1 DESCRIPTION
 
