@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Install.pm 210 2007-02-10 12:53:52Z hikarin $
+# $Id: Install.pm 283 2007-02-23 13:58:29Z hikarin $
 #
 
 package Img0ch::Plugin::Install;
@@ -186,6 +186,13 @@ sub install {
             },
         }
     );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::Upload::ClamAV',
+            methods => {
+                check => 'bbs.upload.pre',
+            },
+        }
+    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Upload::Expires',
             methods => {
@@ -194,6 +201,13 @@ sub install {
             },
         }
     );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::Upload::MIME',
+            methods => {
+                check => 'bbs.upload.pre',
+            },
+        }
+    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Upload::Note',
             methods => {
