@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Truncate.pm 164 2007-02-02 14:52:06Z hikarin $
+# $Id: Truncate.pm 304 2007-03-03 13:54:40Z hikarin $
 #
 
 package Img0ch::Plugin::Rewrite::Truncate;
@@ -72,7 +72,8 @@ sub from_bbs {
             0x82, 0xdc, 0x82, 0xb5, 0x82, 0xbd, 0x81, 0x45, 0x81,
             0x45, 0x91, 0x53, 0x82, 0xc4, 0x82, 0xf0, 0x93, 0xc7,
             0x82, 0xde, 0x82, 0xc9, 0x82, 0xcd, ),
-            '<a href="', $iObject->{url_to_renderer}->( $key, $resno ), '">',
+            '<a href="', $iObject->{url_to_renderer}->( $key, $resno ),
+            '" onclick="redir(this)">',
             pack( 'C*', 0x82, 0xb1, 0x82, 0xb1 ), '</a>',
             pack( 'C*',
             0x82, 0xf0, 0x89, 0x9f, 0x82, 0xb5, 0x82, 0xc4, 0x82,
@@ -89,8 +90,8 @@ sub from_mobile {
     my ( $iObject, $key, $count, $resno, $text, $param ) = @_;
     $param->{single} and return;
 
-    my $line_max               = $iObject->{max_line_at_mobile};
-    my @splitted_text          = split m{<br\s?/?>}xms, $$text;
+    my $line_max = $param->{line} || $iObject->{max_line_at_mobile};
+    my @splitted_text = split m{<br\s?/?>}xms, $$text;
     my $splitted_text_line_num = scalar @splitted_text;
 
     if ( $splitted_text_line_num > $line_max ) {
