@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Template.pm 198 2007-02-08 13:39:47Z hikarin $
+# $Id: Template.pm 264 2007-02-20 15:15:17Z hikarin $
 #
 
 package Img0ch::Template;
@@ -38,14 +38,14 @@ sub new {
             $tmpldir = delete $setting->{'BBS_TEMPLATE'} || 'default';
         }
     }
-    elsif ( $class eq 'Img0ch::Maple' ) {
+    elsif ( $class eq 'Img0ch::Kernel' or $class eq 'Img0ch::Maple' ) {
         $iConfig = $iObject->get_config();
         $iKernel = $iObject;
         $bbs     = '';
     }
     else {
         Img0ch::Kernel->throw_exception(
-            'Img0ch::BBS or Img0ch::Maple not given');
+            'Img0ch::BBS or Img0ch::Maple(Img0ch::Kernel) not given');
     }
 
     my $uri       = $iConfig->get('Server');
@@ -58,7 +58,8 @@ sub new {
     my $filename = join '/', $tmplbase, $tmpldir, $file;
     -r $filename or $filename = join '/', $tmplbase, 'default', $file;
 
-    my $iTemplate = bless {}, $iClass;
+    my $iRequest = $args->{request};
+    my $iTemplate = bless { __request => $iRequest }, $iClass;
     $iTemplate->{__engine} = _load(
         $iConfig->get('TemplateEngine') || 'HTML::Template',
         {   kernel   => $iKernel,
@@ -73,7 +74,8 @@ sub new {
             uri      => $uri,
             cgipath =>
                 ( $iConfig->get('CGIServer') || join( '/', $uri, 'test' ) ),
-            version => $args->{version},
+            version =>
+                ( $iRequest ? $iRequest->signature() : $args->{version} ),
         },
     );
 
@@ -85,7 +87,8 @@ sub new {
     if ( my $iSetting = $args->{setting} ) {
         my $mode = $iSetting->get('BBS_MODE');
         my $res = $mode eq 'picture' ? 1 : 0;
-        my $thread = $mode eq 'news' ? 1 : 0;
+        my $thread = ( $iSetting->is_checked(
+            'BBS_IMG_UPLOAD_THREAD') || $mode eq 'news' ) ? 1 : 0;
         $iTemplate->param({
             Uploadable => ( $res || $thread ),
             UploadableFromRes => $res,
@@ -104,7 +107,13 @@ sub to_string {
     return ( ref $filter || '' ) eq 'CODE' ? \$filter->($buffer) : $buffer;
 }
 
-sub flush { print ${ $_[0]->to_string( $_[1] ) } }
+sub flush {
+    my ( $iTemplate, $filter ) = @_;
+    my $iRequest = $iTemplate->{__request};
+    my $buffer = $iTemplate->to_string($filter);
+    $iRequest ? $iRequest->print($buffer) : print $$buffer;
+    return;
+}
 
 sub save {
     my ( $iTemplate, $path, $filter ) = @_;
@@ -263,8 +272,6 @@ SETTING.TXTにある全ての値を利用することが出来ます。
 使用しているバージョンとimg0ch-config.cgiのI<Seed>を
 MD5関数に渡して得られた結果を返します。
 
-=back
-
 =item Uploadable
 
 掲示板がファイルのアップロードに対応しているかの真偽値を返します。
