@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: CS.pm 73 2007-01-06 12:16:49Z hikarin $
+# $Id: CS.pm 296 2007-03-01 13:48:43Z hikarin $
 #
 
 package Img0ch::Template::CS;
@@ -40,7 +40,7 @@ sub new {
             TimeStamp       => time(),
             VERSION         => $args->{version},
             Version         => Img0ch::Kernel->VERSION(),
-            'hdf.loadpaths' => $args->{tmplpath},
+            'hdf.loadpaths' => [ $args->{tmplpath} ],
             %{ $args->{setting} },
         }
     );
@@ -58,7 +58,8 @@ sub param {
 sub render {
     my ($iTemplate) = @_;
     my $cs = ClearSilver::CS->new( $iTemplate->{__hdf} );
-    $cs->parseFile( $iTemplate->{__file} );
+    $cs->parseFile( $iTemplate->{__file} )
+        or die 'ClearSilver RENDERING ERROR: ', $!;
     \$cs->render();
 }
 
